@@ -1,3 +1,5 @@
+// #![allow(clippy::needless_return)]
+
 use flowync::Flower;
 
 #[test]
@@ -10,7 +12,7 @@ fn drive() {
             for i in 1..20 {
                 handle.send(i);
             }
-            return handle.ok("Ok".to_string());
+            handle.ok("Ok".to_string());
         }
     });
 
@@ -20,15 +22,15 @@ fn drive() {
 
     loop {
         if flower.is_active() {
-            flower
-                .try_recv(|channel| {
+            flower.then(
+                |channel| {
                     if let Some(value) = channel {
                         received_last_value = value;
                         sum += value;
                         println!("{}", value);
                     }
-                })
-                .on_complete(|result| {
+                },
+                |result| {
                     match result {
                         Ok(value) => {
                             assert_eq!("Ok", &value);
@@ -37,7 +39,8 @@ fn drive() {
                     }
 
                     exit = true;
-                });
+                },
+            );
         }
 
         if exit {
